/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2024 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.3.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Glyn EVBRX63N eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#ifdef __RX
  #define EVENACCESS  __evenaccess
#else
  #define EVENACCESS
#endif

/****** Addresses of sfrs and peripheral identifiers ****************/

#define P2_BASE_ADDR       (0x0008C000u)
#define PC_BASE_ADDR       (0x0008C000u)

/****** SFRs and identifiers used for LED demo **********************/

#define P2_DDR             (*(volatile EVENACCESS unsigned char*) (P2_BASE_ADDR + 0x02u))
#define P2_DR              (*(volatile EVENACCESS unsigned char*) (P2_BASE_ADDR + 0x22u))
#define PC_DDR             (*(volatile EVENACCESS unsigned char*) (PC_BASE_ADDR + 0x0Cu))
#define PC_DR              (*(volatile EVENACCESS unsigned char*) (PC_BASE_ADDR + 0x2Cu))

/****** Assign LEDs to Ports ****************************************/

#define LED0_BIT           (5u)      // LED 0 on EVBRX63N is on PC5
#define LED1_BIT           (4u)      // LED 1 on EVBRX63N is on P24
#define LED0_MASK          (1u << LED0_BIT)
#define LED1_MASK          (1u << LED1_BIT)

#define LED0_PORT_DATA      PC_DR
#define LED0_PORT_DIRECTION PC_DDR
#define LED1_PORT_DATA      P2_DR
#define LED1_PORT_DIRECTION P2_DDR

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  LED0_PORT_DATA      |= LED0_MASK;  // Switch off LED0 initially (active low)
  LED0_PORT_DIRECTION |= LED0_MASK;  // Switch LED-Port to output
  LED1_PORT_DATA      |= LED1_MASK;  // Switch off LED0 initially (active low)
  LED1_PORT_DIRECTION |= LED1_MASK;  // Switch LED-Port to output
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    LED0_PORT_DATA &= ~(LED0_MASK);  // Switch LED on, active low
  } else if (Index == 1) {
    LED1_PORT_DATA &= ~(LED1_MASK);  // Switch LED on, active low
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    LED0_PORT_DATA |= (LED0_MASK);  // Switch LED off, set port high
  } else if (Index == 1) {
    LED1_PORT_DATA |= (LED1_MASK);  // Switch LED off, set port high
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    LED0_PORT_DATA ^= LED0_MASK;
  } else if (Index == 1) {
    LED1_PORT_DATA ^= LED1_MASK;
  }
}

/****** End Of File  ************************************************/
