/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2024 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.3.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for RSKRX66N RTK
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#ifdef __RX
  #define EVENACCESS  __evenaccess
#else
  #define EVENACCESS
#endif

#define LED0          (1u << 2u)  // Pin 18, connected to port P32, green, low active
#define LED1          (1u << 3u)  // Pin 17, connected to port P33, green, low active 
                         
#define P3_BASE_ADDR  (0x0008C003u)
#define P3_PDR        (*(volatile EVENACCESS unsigned char*) (P3_BASE_ADDR + 0x00u))
#define P3_PODR       (*(volatile EVENACCESS unsigned char*) (P3_BASE_ADDR + 0x20u))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Switch off LEDs
  //
  P3_PODR |= LED0 | LED1;
  //
  // Set I/O ports to output
  //
  P3_PDR |= LED0 | LED1;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  switch (Index) {
    case 0:
      P3_PODR &= ~LED0;
      break;
    case 1:
      P3_PODR &= ~LED1;
      break;
    default:
      break;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  switch (Index) {
    case 0:
      P3_PODR |= LED0;
      break;
    case 1:
      P3_PODR |= LED1;
      break;
    default:
      break;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  switch (Index) {
    case 0:
      P3_PODR ^= LED0;
      break;
    case 1:
      P3_PODR ^= LED1;
      break;
    default:
      break;
  }
}

/*************************** End of file ****************************/
